==> kubernetes-model-batch-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/PodFailurePolicyOnExitCodesRequirementFluent.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface PodFailurePolicyOnExitCodesRequirementFluent<A extends PodFailurePolicyOnExitCodesRequirementFluent<A>> extends Fluent<A>{
  public String getContainerName();
  public A withContainerName(String containerName);
  public Boolean hasContainerName();
  public String getOperator();
  public A withOperator(String operator);
  public Boolean hasOperator();
  public A addToValues(Integer index,Integer item);
  public A setToValues(Integer index,Integer item);
  public A addToValues(java.lang.Integer... items);
  public A addAllToValues(Collection<Integer> items);
  public A removeFromValues(java.lang.Integer... items);
  public A removeAllFromValues(Collection<Integer> items);
  public List<Integer> getValues();
  public Integer getValue(Integer index);
  public Integer getFirstValue();
  public Integer getLastValue();
  public Integer getMatchingValue(Predicate<Integer> predicate);
  public Boolean hasMatchingValue(Predicate<Integer> predicate);
  public A withValues(List<Integer> values);
  public A withValues(java.lang.Integer... values);
  public Boolean hasValues();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> kubernetes-model-batch-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/PodFailurePolicyOnExitCodesRequirementFluent.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodFailurePolicyOnExitCodesRequirementFluent<A extends PodFailurePolicyOnExitCodesRequirementFluent<A>> extends Fluent<A>{
  public String getContainerName();
  public A withContainerName(String containerName);
  public Boolean hasContainerName();
  public String getOperator();
  public A withOperator(String operator);
  public Boolean hasOperator();
  public A addToValues(int index,Integer item);
  public A setToValues(int index,Integer item);
  public A addToValues(java.lang.Integer... items);
  public A addAllToValues(Collection<Integer> items);
  public A removeFromValues(java.lang.Integer... items);
  public A removeAllFromValues(Collection<Integer> items);
  public List<Integer> getValues();
  public Integer getValue(int index);
  public Integer getFirstValue();
  public Integer getLastValue();
  public Integer getMatchingValue(Predicate<Integer> predicate);
  public Boolean hasMatchingValue(Predicate<Integer> predicate);
  public A withValues(List<Integer> values);
  public A withValues(java.lang.Integer... values);
  public Boolean hasValues();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
